@@ -87,6 +87,9 @@ public:
     void setFont(const QFont &font);
 
     void setEnableBalooSearch(bool enable);
+    bool enableBalooSearch() const;
+    void setEnableAkonadiSearch(bool enable);
+    bool enableAkonadiSearch() const;
 
     bool isCompletionEnabled() const;
 
@@ -220,10 +223,9 @@ protected:
     void insertEmails(const QStringList &emails);
     void loadContacts();
 
-private Q_SLOTS:
+private:
     void groupExpandResult(KJob *job);
     void slotToggleExpandGroups();
-private:
     bool eventFilter(QObject *, QEvent *) Q_DECL_OVERRIDE;
 
     AddresseeLineEditPrivate *const d;
