@@ -61,6 +61,7 @@ AddresseeLineEditPrivate::AddresseeLineEditPrivate(KPIM::AddresseeLineEdit *qq,
       m_useSemicolonAsSeparator(false),
       m_showOU(false),
       m_enableBalooSearch(true),
+      m_enableAkonadiSearch(true),
       mExpandIntern(true),
       mAutoGroupExpand(false),
       mShowRecentAddresses(true),
@@ -490,7 +491,9 @@ void AddresseeLineEditPrivate::slotTriggerDelayedQueries()
 
     // We send a contactsearch job through akonadi.
     // This not only searches baloo but also servers if remote search is enabled
-    akonadiPerformSearch();
+    if (m_enableAkonadiSearch) {
+        akonadiPerformSearch();
+    }
 }
 
 void AddresseeLineEditPrivate::startSearches()
@@ -513,7 +516,7 @@ void AddresseeLineEditPrivate::akonadiPerformSearch()
     s_static->akonadiJobsInFlight.clear();
 
     // now start new jobs
-    Akonadi::ContactSearchJob *contactJob = new Akonadi::ContactSearchJob(s_static->akonadiSession);
+    Akonadi::ContactSearchJob *contactJob = new Akonadi::ContactSearchJob(s_static->akonadiSession());
     contactJob->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
     contactJob->setQuery(Akonadi::ContactSearchJob::NameOrEmail, m_searchString,
                          Akonadi::ContactSearchJob::ContainsWordBoundaryMatch);
@@ -522,7 +525,7 @@ void AddresseeLineEditPrivate::akonadiPerformSearch()
     connect(contactJob, &KJob::result,
             this, &AddresseeLineEditPrivate::slotAkonadiSearchResult);
 
-    Akonadi::ContactGroupSearchJob *groupJob = new Akonadi::ContactGroupSearchJob(s_static->akonadiSession);
+    Akonadi::ContactGroupSearchJob *groupJob = new Akonadi::ContactGroupSearchJob(s_static->akonadiSession());
     groupJob->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
     groupJob->setQuery(Akonadi::ContactGroupSearchJob::Name, m_searchString,
                        Akonadi::ContactGroupSearchJob::ContainsMatch);
@@ -803,7 +806,7 @@ void AddresseeLineEditPrivate::slotAkonadiHandleItems(const Akonadi::Item::List
             Akonadi::CollectionFetchJob *collectionJob =
                 new Akonadi::CollectionFetchJob(item.parentCollection(),
                                                 Akonadi::CollectionFetchJob::Base,
-                                                s_static->akonadiSession);
+                                                s_static->akonadiSession());
             connect(collectionJob, &Akonadi::CollectionFetchJob::collectionsReceived,
                     this, &AddresseeLineEditPrivate::slotAkonadiCollectionsReceived);
             /* we don't want to start multiple fetch jobs for the same collection,
@@ -994,6 +997,16 @@ void AddresseeLineEditPrivate::setEnableBalooSearch(bool enableBalooSearch)
     m_enableBalooSearch = enableBalooSearch;
 }
 
+bool AddresseeLineEditPrivate::enableAkonadiSearch() const
+{
+    return m_enableAkonadiSearch;
+}
+
+void AddresseeLineEditPrivate::setEnableAkonadiSearch(bool enableAkonadiSearch)
+{
+    m_enableAkonadiSearch = enableAkonadiSearch;
+}
+
 QString AddresseeLineEditPrivate::searchString() const
 {
     return m_searchString;
